# mocker fixture becomes available after installing pytest-mock
# https://github.com/pytest-dev/pytest-mock
def test_ping_matomo(mocker):
  from .matomo_sdk_py import ping_matomo
  def mockreturn(*args, **kwargs): return "foo"
  mocked_post = mocker.patch('matomo_sdk_py.matomo_sdk_py.requests.post', side_effect=mockreturn)
  ping_matomo("/test", "https://example.com", 1, "abcdef", "https://example.matomo.cloud")

  # check that mocked object is called
  # https://github.com/pytest-dev/pytest-mock/commit/68868872195135bdb90d45a5cb0d609400943eae
  mocked_post.assert_called()



import requests
SKIP_PING=False
def ping_matomo(action_name, action_base, idsite, uuid_val, matomo_url):
  """
  Gather anonymous usage statistics

  action_name - same field in matomo
  action_base - website URL in matomo, e.g. https://example.com
  idsite - integer representing ID of website in matomo
  uuid_val - matomo field "uid"
  matomo_url - URL of matomo host, eg https://example.matomo.cloud/piwik.php
  """
  # if any previous failure, just skip it completely
  global SKIP_PING # http://stackoverflow.com/questions/423379/ddg#423596 
  if SKIP_PING:
      return

  from urllib.parse import urljoin, urlencode

  # build action url
  # https://stackoverflow.com/questions/9718541/reconstructing-absolute-urls-from-relative-urls-on-a-page#comment51058834_9718651
  action_url = urljoin(action_base, action_name)

  # https://stackoverflow.com/a/39144239/4126114
  req_i = {
    "idsite": idsite,
    "rec": 1,
    "action_name": action_name,
    "uid": uuid_val,

    # use the same UID for matomo's visitor ID.
    # More info at:
    # https://matomo.org/docs/user-id/
    # https://developer.matomo.org/api-reference/tracking-api
    "cid": uuid_val,

    "url": action_url
  }
  payload = {"requests": ["?"+urlencode(req_i)]}

  # use POST instead of GET to avoid arguments showing up in the clear
  # https://developer.matomo.org/api-reference/tracking-api
  try:
    response = requests.post(matomo_url, json=payload, timeout=1) # 1 second
  except requests.exceptions.ConnectionError as error:
    # just ignore the failure to connect
    # in order not to obstruct the CLI
    SKIP_PING=True
    pass
  except requests.exceptions.ReadTimeout as error:
      # also ignore
      SKIP_PING=True
      pass




from setuptools import setup, find_packages

# copied from https://github.com/awslabs/git-remote-codecommit/blob/master/setup.py
import os
def read(fname):
  return open(os.path.join(os.path.dirname(__file__), fname)).read()
  

from matomo_sdk_py import matomoSdkPy_version

# follow https://github.com/awslabs/git-remote-codecommit/blob/master/setup.py
# and https://packaging.python.org/tutorials/packaging-projects/
setup(
    name='matomo_sdk_py',
    version=matomoSdkPy_version,
    author="Shadi Akiki, AutofitCloud",
    author_email="shadi@autofitcloud.com",
    url='https://gitlab.com/autofitcloud/matomoSdkPy',
    description="Python SDK to send POST http requests to matomo",

    # 2019-09-10 not sure what in the README.md is yielding the twine error
    # The description failed to render in the default format of reStructuredText.
    # long_description = read('README.md'),
    long_description = 'Check repository link',
    long_description_content_type="text/markdown",
    
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'requests==2.22.0',
    ],
)
